/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.fusion.fusionbackend.repository;

import io.fusion.fusionbackend.model.AssetType;
import io.fusion.fusionbackend.model.AssetTypeTemplate;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.repository.EntityGraph;
import org.springframework.data.repository.PagingAndSortingRepository;

import java.util.List;
import java.util.Optional;
import java.util.Set;

public interface AssetTypeTemplateRepository extends PagingAndSortingRepository<AssetTypeTemplate, Long> {
    Sort DEFAULT_SORT = Sort.by("id").ascending();

    @EntityGraph(value = "AssetTypeTemplate.allChildren")
    Set<AssetTypeTemplate> findAll(Sort sort);

    @EntityGraph(value = "AssetTypeTemplate.allChildren")
    Optional<AssetTypeTemplate> findById(Long assetTypeTemplateId);

    @EntityGraph(value = "AssetTypeTemplate.allChildrenDeep")
    Optional<AssetTypeTemplate> findDeepById(Long assetTypeTemplateId);

    @EntityGraph(value = "AssetTypeTemplate.allChildren")
    List<AssetTypeTemplate> findAllByAssetType(AssetType assetType);

    @EntityGraph(value = "AssetTypeTemplate.allChildren")
    List<AssetTypeTemplate> findAllByAssetTypeId(Long assetTypeId);

    Set<AssetTypeTemplate> findSubsystemCandidates(Long parentAssetTypeId, Long assetTypeTemplateId);

    Set<Long> findAllSubsystemIds();

    Set<AssetTypeTemplate> findPeerCandidates(Long assetTypeTemplateId, Long assetTypeTemplateId2);

    Set<Long> findAllPeerIds();
}
