/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

// -------------------------------------------------
// Models of request (do not change names!), see https://kairosdb.github.io/docs/restapi/QueryMetrics.html#id3
export class KairosRequest {
  // tslint:disable-next-line:variable-name
  start_absolute: number;
  // tslint:disable-next-line:variable-name
  end_absolute?: number;
  metrics: MetricsWithAggregationAndGrouping[];
}

export class MetricsWithAggregationAndGrouping {
  name: string;
  limit?: number;
  // tslint:disable-next-line:variable-name
  group_by: KairosGroupBy[];
  aggregators: KairosAggregator[];
}

/**
 * @see https://kairosdb.github.io/docs/restapi/TimeGrouping.html (time)
 * @see https://kairosdb.github.io/docs/restapi/ValueGrouping.html (value)
 */
export class KairosGroupBy {

  /**
   *  global unique field name
   */
  name: string;

  // tslint:disable-next-line:variable-name
  range_size: number;
  group?: KairosGroup;
}

export class KairosGroup {
  // tslint:disable-next-line:variable-name
  group_number: number;
}

/**
 * @see https://kairosdb.github.io/docs/restapi/Aggregators.html?highlight=aggregator
 */
export class KairosAggregator {

  /**
   * Possible values: 'avg', 'count', ...
   */
  name: string;
  sampling?: KairosSampling;
}

export class KairosSampling {
  unit: string;
  value: number;
}


// -------------------------------------------------
// Models of response (do not change names!), see https://kairosdb.github.io/docs/restapi/QueryMetrics.html#response
export class KairosResponse {
  queries: KairosQuery[];
}

export class KairosQuery {
  // tslint:disable-next-line:variable-name
  sample_size: number;
  results: KairosResult[];
}

export class KairosResult {
  name: string;
  // tslint:disable-next-line:variable-name
  group_by: KairosGroupBy[];
  tags: KairosTags;

  /**
   * each second array consists of timestamp [0] and an (aggregated) data value [1]
   */
  values: number[][];
}

export class KairosTags {
  type: string[];
}


// -------------------------------------------------
// Models of converted response

/**
 * KairosResult.values converted into a more readable format,
 * iterated over results of queries (usually length 1 each for single field-query)
 */
export class KairosDataPointGroup {
  index: number;
  timestamps?: number[];
  values: number[];
}

export class KairosDataPoint {
  timestamp: number;
  value: number;
}

export enum DeviceStatus {
  OFFLINE = 0,
  IDLE = 1,
  RUNNING = 2,
  ERROR = 3
}

/** example:
 *  {
 *   "id" : "urn:ngsi-ld:asset:2:1",
 *   "type" : "MSF",
 *   "no_starts" : "2",
 *   "plate_thickness" : "3",
 *   "subsystems" : [ ],
 *   "total_cutting_time" : "",
 *   "status" : "1"
 *  }
 */
export declare type ngsiLdLatestKeyValues = any;
